@@ -18,6 +18,7 @@ from .construct import (
     aspolynomial,
     clean_attributes,
     polynomial_from_attributes,
+    polynomial_from_roots,
     monomial,
     symbols,
     variable,
@@ -46,10 +47,11 @@ def get_version(name):
         True
 
     """
+    version = None
     try:
         version = pkg_resources.get_distribution(name).version
     except pkg_resources.DistributionNotFound:
-        version = None
+        pass
     return version
 
 
