@@ -54,7 +54,4 @@ def equal(x1, x2, out=None, where=True, **kwargs):
         return numpy.bool_(equal(x1.ravel(), x2.ravel(), out=out.ravel()).item())
     for coeff1, coeff2 in zip(x1.coefficients, x2.coefficients):
         out &= numpy.equal(coeff1, coeff2, where=where, **kwargs)
-
-    if not out.size:
-        out = numpy.bool_(out)
     return out
