@@ -70,8 +70,5 @@ def greater_equal(x1, x2, out=None, **kwargs):
         indices = (coefficients1[idx] != 0) | (coefficients2[idx] != 0)
         indices &= coefficients1[idx] != coefficients2[idx]
         out[indices] = numpy.greater_equal(
-            coefficients1[idx][indices], coefficients2[idx][indices], **kwargs)
-
-    if not out.size:
-        out = bool(out)
+            coefficients1[idx], coefficients2[idx], **kwargs)[indices]
     return out
