@@ -20,25 +20,29 @@ def hsplit(ary, indices_or_sections):
     Examples:
         >>> poly = numpoly.monomial(8).reshape(2, 4)
         >>> poly
-        polynomial([[1, q, q**2, q**3],
-                    [q**4, q**5, q**6, q**7]])
+        polynomial([[1, q0, q0**2, q0**3],
+                    [q0**4, q0**5, q0**6, q0**7]])
         >>> part1, part2 = numpoly.hsplit(poly, 2)
         >>> part1
-        polynomial([[1, q],
-                    [q**4, q**5]])
+        polynomial([[1, q0],
+                    [q0**4, q0**5]])
         >>> part2
-        polynomial([[q**2, q**3],
-                    [q**6, q**7]])
+        polynomial([[q0**2, q0**3],
+                    [q0**6, q0**7]])
         >>> part1, part2, part3 = numpoly.hsplit(poly, [1, 2])
         >>> part1
         polynomial([[1],
-                    [q**4]])
+                    [q0**4]])
         >>> part3
-        polynomial([[q**2, q**3],
-                    [q**6, q**7]])
+        polynomial([[q0**2, q0**3],
+                    [q0**6, q0**7]])
 
     """
     ary = numpoly.aspolynomial(ary)
     results = numpy.hsplit(ary.values, indices_or_sections=indices_or_sections)
-    return [numpoly.aspolynomial(result, names=ary.indeterminants)
-            for result in results]
+    return [
+        numpoly.polynomial(
+            result, names=ary.indeterminants, allocation=ary.allocation,
+        )
+        for result in results
+    ]
